import { ItemAddResult, ItemUpdateResult, CamlQuery } from "@pnp/sp";
export declare class ItemService {
    /**
     * Get item by Id
     * @param listName string
     * @param itemId number
     */
    getListItemById<T>(listName: string, Id: number): Promise<T>;
    /**
     * Get item by Id
     * @param listName string
     * @param expand String query expand fields
     * @param select String query select fields
     * @param Id Item id number
     */
    getListItemByIdQuery<T>(listName: string, expand: string, select: string, Id: number): Promise<T>;
    /**
     * Add item
     * @param listName string
     * @param model any
     */
    ItemAdd(listName: string, model: any): Promise<ItemAddResult>;
    /**
     * Update item
     * @param listName string
     * @param model any
     */
    ItemUpdate(listName: string, model: any): Promise<ItemUpdateResult>;
    /**
     * Delete item
     * @param listName string
     * @param itemId number
     */
    ItemDelete(listName: string, itemId: number): Promise<boolean>;
    /**
     * Get items list is in Root Web
     * @param listName name list
     * @param expands expand
     * @param selects selects
     * @param filter filter
     */
    static getRootWebListItems<T>(listName: string, expands?: string, selects?: string, filter?: string): Promise<Array<T>>;
    /**
     * Get items list is Current Web
     * @param listName name list
     * @param expands expand
     * @param selects selects
     * @param filter filter
     */
    static getWebListItems<T>(listName: string, expands?: string, selects?: string, filter?: string): Promise<Array<T>>;
    /**
     * Get items list
     * @param listName name list
     * @param expands expand
     * @param selects selects
     * @param filter filter
     */
    private static getListItems;
    /**
     * Get items list is in Root Web By CAML QUERY
     * @param listName name list
     * @param expands expand
     * @param camlQuery camQuery
     */
    static getRootWebListItemsCAMLQuery<T>(listName: string, camlQuery: CamlQuery, expands?: string[]): Promise<Array<T>>;
    /**
     * Get items list is in Current Web By CAML QUERY
     * @param listName name list
     * @param expands expand
     * @param camlQuery camQuery
     */
    static getWebListItemsCAMLQuery<T>(listName: string, camlQuery: CamlQuery, expands?: string[]): Promise<Array<T>>;
    /**
     * Get items list By CAML QUERY
     * @param listName name list
     * @param expands expand
     * @param camlQuery camQuery
     */
    private static getListItemsCAMLQuery;
}
